function [Stationary,X,Z,stationarycover,Damping,relchange]=Bayes_sample_percent_cover2(Y,reps,tmax,Avcoral,Avalgae,Nstart,beta,x,yal,yalcover,plotfigs)
%Bayesian estimation of stationary distribution and trajectory over time
%for a discrete-time Markov model
%SYNTAX
%[Stationary,X,Z,stationarycover,Damping,relchange]=Bayes_sample_percent_cover2(Y,reps,tmax,Avcoral,Avalgae,Nstart,beta,x,yal,yalcover,plotfigs)
%INPUTS
%Y is a matrix of transition counts (not probabilities), with element i,j
%being number of transitions observed from j to i
%reps is the number of replicates to sample from the posterior distribution
%of the transition probability matrix
%tmax is the number of time steps to iterate the Markov model
%Avcoral&Avalgae are the avaerage percentage cover of coral and algae in
%each state.
%Nstart is initial state count vector (e.g. from 2005 or most recent survey)
%beta (optional) is a square matrix (same size as Y) of directions of change in each
%transition probability (typically contains only -1, 0 and 1 values). The
%diagonal should be zeros.
%x (optional) is the size of change in a dummy explanatory variable (which we treat as
%if it's centred at the value that applies to the input transition matrix
%P)
%Beta and x specify a change scenario.
%If beta and x specified, use multinomial_logit.m to make the specified
%change to each transition probability matrix after sampling and before
%calculating any summary statistics
%yal and yalcover (optional) are vertical axis limits for time plots
%(choose sensible values if not specified)
%if plotfigs (optional, default 1) is zero, don't plot figures
%OUTPUTS
%Stationary is a matrix of stationary distribution estimates, one
%row per state, one column per replicate
%X is a three-dimensional array of expected state probabilities at times 0:tmax, one row per
%state, one column per time, one layer per replicate
%Z is a three-dimensional array of expected percentage cover at times 0:tmax, coral in row 1,
%algae in row 2, one column per time, one layer per replicate
%stationarycover is two rows for the percentage coral and algal cover at
%equilibrium point at each replicate
%Damping is the damping ratio representing how fast the equilibrium state
%is reached
%relchange is a vector of mean absolute proportional change in transition
%probabilities under the specified scenario (all zeros if beta, x not
%supplied)
%USES
%Pposterior.m
%sorted_eigs.m
%timeplot_summary2.m
%multinomial_logit.m

if nargin<7
    beta=[];
end
if nargin<8
    x=[];
end
if nargin<9
    yal=[];
end
if nargin<10
    yalcover=[];
end
if nargin<11
    plotfigs=1;
end

S=size(Y,1);
Stationary=zeros(S,reps);
X=zeros(S,tmax+1,reps);
Z=zeros(2,tmax+1,reps);
stationarycover=zeros(2,reps);
Damping=zeros(1,reps);
relchange=zeros(1,reps);

if plotfigs
    figure(1);
    clf;
    hold on;

    figure(2);
    clf;
    hold on;
end

for i=1:reps %for reps number of random transitions
    Ppost=Pposterior(Y); %generates random transitions, random sample from the number of transitions, represents uncertainty
    
    %make changes to Ppost according to scenario
    if ~isempty(beta)
        Ppostm=multinomial_logit(Ppost,beta,x);
        cs=abs((Ppostm-Ppost)./Ppost);
        relchange(i)=mean(cs(:));%mean proportional absolute change in transition probabilities under scenario
        Ppost=Ppostm;
    end
    
    [lambda,W,V]=sorted_eigs(Ppost); %sorts eigenvalues, largest, scales eigenvectors 
    Stationary(:,i)=W(:,1); %chooses eigenvector that represents stable distribution
    Damping(i)=lambda(1)/abs(lambda(2));
    Eq=Stationary(:,i);
    stationarycover(1,i)=sum(Eq.*Avcoral); %.*used to multiply values in bracket giving the coral cover at equilibrium
    stationarycover(2,i)=sum(Eq.*Avalgae);
    Pstart=Pposterior(Nstart); %Samples from posterior distribution of initial transition frequencies
    X(:,1,i)=Pstart;
    Z(1,1,i)=sum(X(:,1,i).*Avcoral); %.*used to multiply values in bracket giving the coral cover at equilibrium
    Z(2,1,i)=sum(X(:,1,i).*Avalgae);
    for t=1:tmax
        X(:,t+1,i)=Ppost*X(:,t,i); %do the calculation one time step at a time
        Z(1,t+1,i)=sum(X(:,t+1,i).*Avcoral); %.*used to multiply values in bracket giving the coral cover at equilibrium
        Z(2,t+1,i)=sum(X(:,t+1,i).*Avalgae);
    end
end

if plotfigs
    %box plot of state proportions at equilibrium
    yalbox=[0 0.8];
    figure (3);
    boxplot(Stationary');
    set(gca,'xtick',1:6,'xticklabel',{'A','B','C','D','E','F'});
    set(gca,'ylim',yalbox);

    %ylbl='Proportion'
    if isempty(yal)
        yal=[0 0];
        figure(1);
        %first pass to get sensible limits
        for i=1:S
            subplot(3,2,i);
            timeplot_summary2(X*100,[0.95 0.5],i,'Year','Percentage',Stationary);%asks for 95 and 50% credible intervals
            ys=get(gca,'ylim');
            if ys(2)>yal(2)
                yal(2)=ys(2);
            end
        end
    end
    %second pass for figure we want
    figure(1);
    clf;
    titles={'A','B','C','D','E','F'};%list of titles we want
    for i=1:S
        subplot(3,2,i);
        timeplot_summary2(X*100,[0.95 0.5],i,'Year','Percentage',Stationary,yal);%asks for 95 and 50% credible intervals
        xl=get(gca,'xlim');
        text(xl(1)+0.1*(xl(2)-xl(1)),yal(2)-0.1*(yal(2)-yal(1)),titles{i});%position the title in top left corner, using current axis limits to work out where that is
    end

    if isempty(yalcover)
        yalcover=[0 35];%need to calculate y axis limit separately for this figure
        figure (2);
        %first pass: get sensible limits
        for i=1:2;
            subplot(2,1,i);
            timeplot_summary2(Z,[0.95 0.5],i,'Year','Percentage cover',stationarycover/100);
            ys=get(gca,'ylim');
            if ys(2)>yalcover(2)
                yalcover(2)=ys(2);
            end
        end
    end
    %second pass: the figure we actually want
    figure(2);
    clf;
    titles={'A: coral','B: macroalgae'};
    for i=1:2;
        subplot(2,1,i);
        timeplot_summary2(Z,[0.95 0.5],i,'Year','Percentage cover',stationarycover/100,yalcover);
        xl=get(gca,'xlim');
        text(xl(1)+0.1*(xl(2)-xl(1)),yalcover(2)-0.05*(yalcover(2)-yalcover(1)),titles{i});%position the title in top left corner, using current axis limits to work out where that is
    end
end