function scenario_summary(levels,xlbl,ylbl,scarray,x,statevar,yal,title)
%plot credible intervals of stationary cover from Bayesian markov model
%under a range of scenarios
%SYNTAX
%scenario_summary(levels,xlbl,ylbl,scarray,x,statevar,yal,title)
%INPUTS
%levels is either (if scalar) the number of equally-spaced equal-tailed credible intervals we want (e.g.
%levels=4 gives us 20, 40, 60, and 80% equal-tailed credible intervals) or
%(if vector) the actual credible intervals we want (e.g. [0.95 0.5] gives us
%95% and 50% equal-tailed credible intervals (give the intervals in order of decreasing width).
%state is the state (row of X) for which we want the summary plot
%xlbl is a label for the horizontal axis
%ylbl is a label for the vertical axis
%scarray is a 3-dimensional array of data: rows are coral and algae, columns are replicates,
%layers are values of explanatory variable x
%x is a vector of values of an explanatory variable
%statevar is the state variable (1 for coral, 2 for algae) we want to plot
%yal (optional) is y axis limits (want to set these the same for all panels)
%title (optional) is panel label
%OUTPUTS
%A plot of credible intervals for stationary cover of coral and algae at
%each of the values in x
%USES
%format_ticks.m (Central File Exchange)

if nargin<7
    yal=[];
end
if nargin<8
    title=[];
end

nx=length(x);
nreps=size(scarray,2);
statevdata=scarray(statevar,:,:);
statevdata=reshape(statevdata,nreps,nx);


cla;%clear the current axes
hold on;
if ~isempty(yal)
    set(gca,'ylim',yal);
end

if isscalar(levels)%we supplied the number of levels we want
    clevel=0:1/(levels+1):1;
    clevel=clevel(2:end-1)/2;
else%we supplied the levels we want
    clevel=(1-levels)/2;
end
carray=(1-clevel)*0.8;
carray=repmat(carray,[1,1,3]);

%find the credible intervals at each explanatory value
qlow=quantile(statevdata,clevel);
qhigh=quantile(statevdata,1-clevel);
xdata=[x';(fliplr(x))';x(1)];
ydata=[qhigh';qlow(:,nx:-1:1)';qhigh(:,1)'];
patch(xdata(:,ones(1,size(ydata,2))),ydata,carray,'edgecolor','none');

%add posterior mean
pm=mean(statevdata);
plot(x,pm,'k-');

%label axes
xlabel(xlbl,'fontname','Arial');
ylabel(ylbl,'fontname','Arial');
set(gca,'fontname','Arial');
if ~isempty(title)
    xl=get(gca,'xlim');
    if isempty(yal)
        yal=get(gca,'ylim');
    end
    text(xl(1)+0.1*(xl(2)-xl(1)),yal(2)-0.1*(yal(2)-yal(1)),title,'fontname','Arial');%position the title in top left corner, using current axis limits to work out where that is
end
