function [pm,qlow,qhigh]=timeplot_summary2(X,levels,state,xlbl,ylbl,Stationary,yal)
%plot credible intervals of trajectory from Bayesian markov model
%This version: also put stationary distribution on same graph
%SYNTAX
%[pm,qlow,qhigh]=timeplot_summary2(X,levels,state,xlbl,ylbl,Stationary,yal)
%INPUTS
%X is a 3-dimensional array of data: rows are states, columns are times,
%layers are replicate samples from the posterior distribution
%levels is either (if scalar) the number of equally-spaced equal-tailed credible intervals we want (e.g.
%levels=4 gives us 20, 40, 60, and 80% equal-tailed credible intervals) or
%(if vector) the actual credible intervals we want (e.g. [0.95 0.5] gives us
%95% and 50% equal-tailed credible intervals (give the intervals in order of decreasing width).
%state is the state (row of X) for which we want the summary plot
%xlbl is a label for the horizontal axis
%ylbl is a label for the vertical axis
%Stationary is a 2-d array of stationary state probabilities. Rows are
%states, cols are replicates
%yal (optional) is y axis limits (want to set these the same for all panels)
%OUTPUTS
%A time plot showing credible intervals (narrowest are darkest) and the
%posterior mean (as a solid black line)
%pm is a vector of posterior means at each time
%qlow is a matrix of lower bounds of the requested credible intervals at
%each time
%qhigh is a matrix of lower bounds of the requested credible intervals at
%each time
%USES
%format_ticks.m (Central File Exchange)

if nargin<7
    yal=[];
end

tmax=size(X,2)-1;
nreps=size(X,3);
statedata=X(state,:,:);
statedata=(reshape(statedata,tmax+1,nreps))';

cla;%clear the current axes
hold on;
if ~isempty(yal)
    set(gca,'ylim',yal);
end

if isscalar(levels)%we supplied the number of levels we want
    clevel=0:1/(levels+1):1;
    clevel=clevel(2:end-1)/2;
else%we supplied the levels we want
    clevel=(1-levels)/2;
end
carray=(1-clevel)*0.8;
carray=repmat(carray,[1,1,3]);

%find the credible intervals at each observation time
qlow=quantile(statedata,clevel);
qhigh=quantile(statedata,1-clevel);
xdata=[(0:tmax)';(tmax:-1:0)';0];
ydata=[qhigh';qlow(:,tmax+1:-1:1)';qhigh(:,1)'];
h=patch(xdata(:,ones(1,size(ydata,2))),ydata,carray,'edgecolor','none');

%add posterior mean
pm=mean(statedata);
plot(0:tmax,pm,'k-');


%add stationary distribution
ts=tmax+1;
tsw=ts+1;
xsdata=[(ts:tsw)';(tsw:-1:ts)';ts];
sdata=100*Stationary(state,:);
qslow=quantile(sdata,clevel);
qshigh=quantile(sdata,1-clevel);
ysdata=[qshigh;qshigh;qslow;qslow;qshigh];
h=patch(xsdata(:,ones(1,size(ysdata,2))),ysdata,carray,'edgecolor','none');

%add posterior mean of stationary distribution
pms=mean(sdata);
plot(ts:tsw,[pms,pms],'k-');

%set last tick label
set(gca,'xtick',[0:tmax,(ts+tsw)/2]);
xtl=cellstr(num2str((0:tmax)'));
set(gca,'xlim',[0 tsw]);
xtl{length(xtl)+1}='\infty';

ytick=get(gca,'YTick');
t1=text(tmax+1/2,0,'//','fontsize',10);
xl = get(gca,'xlabel');
yl = get(gca,'ylabel');
orig_label_units = get( xl, 'Units');
set([xl yl], 'Units','pixels');
xp = get( xl, 'Position');
yp = get( yl, 'Position');
% Generate the text object ticks (changing labels' Position):
format_ticks(gca,xtl);
% Restore original label Position and Units properties:
set( xl, 'Position', xp);
set( yl, 'Position', yp);
set([xl yl], 'Units', orig_label_units);

%label axes
xlabel(xlbl,'fontname','Arial');
ylabel(ylbl,'fontname','Arial');
set(gca,'fontname','Arial');
